@@ -25,7 +25,7 @@
 
 uint32_t version = 0;
 uint32_t options = BO_BLUR;
-char dname[] = "Blur diagonal /";
+char dname[] = "Diagonal blur 2";
 char desc[] = "Diagonal blur";
 
 
