@@ -37,7 +37,7 @@
 #define DEFAULT_COLOR_COUNT 5
 
 uint32_t version = 1;
-uint32_t options = BO_GFX|BO_LENS|BO_IMAGE;
+uint32_t options = BO_GFX | BO_LENS | BO_NOT_LENS | BO_IMAGE;
 enum LayerMode mode = LM_OVERLAY;
 char desc[] = "Show image scrolling colors";
 char dname[] = "Image colrot";
