@@ -26,7 +26,7 @@ const char *direction_list[DIRECTION_NB] = { "Leftwards", "Rightwards", "Bounce"
 
 
 uint32_t version = 0;
-uint32_t options = BO_GFX|BO_IMAGE;
+uint32_t options = BO_GFX | BO_IMAGE | BO_HOR;
 char dname[] = "Scanline X";
 char desc[] = "Horizontal scanline";
 
@@ -36,7 +36,7 @@ on_switch_on(Context_t *ctx)
 {
   direction = RIGHTWARDS;
   current_direction = 1;
-  thickness = 1;
+  thickness = b_rand_int32_range(1, 6);
   set_size();
 }
 
