@@ -173,6 +173,11 @@ run(Context_t *ctx)
     }
 
     fflush(mp4);
+
+    // dump screenshot for reproducibility test
+    if (NULL != getenv("LEBINIOU_DUMP_FRAMES")) {
+      Context_screenshot(ctx, 1);
+    }
   }
 }
 
