@@ -354,13 +354,6 @@ biniou_set_max_fps(const uint8_t fps)
 }
 
 
-void
-biniou_verbosity(const uint8_t v)
-{
-  libbiniou_verbose = v;
-}
-
-
 void
 biniou_set_random_mode(const enum RandomMode r)
 {
