@@ -28,9 +28,9 @@ void b_rand_free(void);
 uint32_t b_rand_int(void);
 int32_t  b_rand_int32_range(const int32_t begin, const int32_t end);
 uint32_t b_rand_uint32_range(const uint32_t begin, const uint32_t end);
-double b_rand_double_range(const double begin, const double end);
-int b_rand_boolean(void);
-void b_rand_set_seed(const uint32_t seed);
+double   b_rand_double_range(const double begin, const double end);
+uint8_t  b_rand_boolean(void);
+void     b_rand_set_seed(const uint32_t seed);
 
 #endif /* _BRANDOM_H */
 
