@@ -29,6 +29,10 @@
 static void
 bulfius_post(const char *endpoint, json_t *body)
 {
+  if (NULL != getenv("LEBINIOU_TEST")) {
+    return;
+  }
+
   struct _u_request req;
 
   ulfius_init_request(&req);
