@@ -39,7 +39,7 @@ extern uint8_t  enable_osd;
 #endif
 extern uint8_t  usage_statistics;
 extern uint8_t  launch_browser;
-
+extern char    *http_instance;
 
 #define MIN_WIDTH  80
 #define MIN_HEIGHT 60
@@ -80,6 +80,7 @@ usage(void)
 #ifdef WITH_SDL2UI
          "\t-G, --enable-sdl2-gui\tEnable the legacy SDL2 GUI\n"
 #endif
+         "\t-I, --instance <name>\tSet the instance name [none]\n"
          "\t-N, --no-statistics\tDo not send usage statistics\n"
          "\t-P, --playlist <file>\tSet playlist file\n"
          "\t-S, --stats\t\tDisplay statistics\n"
@@ -102,7 +103,7 @@ usage(void)
 #ifdef WITH_WEBCAM
          , desired_webcams
 #endif
-        );
+         );
 
   /* TODO print default values for all options */
   exit(0);
@@ -117,7 +118,7 @@ getargs(int argc, char **argv)
   int w, h;
 #endif
 
-  static const char *arg_list = "a:b:c:BC:d:D:EfF:Ghi:lm:nNo:P:qr:sSt:x:X:y:Y:vw:W:z:";
+  static const char *arg_list = "a:b:c:BC:d:D:EfF:GhI:i:lm:nNo:P:qr:sSt:x:X:y:Y:vw:W:z:";
 
 #if HAVE_GETOPT_LONG
   static struct option long_opt[] = {
@@ -152,6 +153,7 @@ getargs(int argc, char **argv)
 #ifdef WITH_SDL2UI
     {"enable-sdl2-gui", no_argument, NULL, 'G'},
 #endif
+    {"instance", required_argument, NULL, 'I'},
     {"no-statistics", no_argument, NULL, 'N'},
     {"playlist", required_argument, NULL, 'P'},
     {"stats", no_argument, NULL, 'S'},
@@ -168,9 +170,9 @@ getargs(int argc, char **argv)
   /* Get command line arguments */
   while ((ch = getopt_long(argc, argv, arg_list, long_opt, NULL)) != -1)
 #else
-  while ((ch = getopt(argc, argv, arg_list)) != -1)
+    while ((ch = getopt(argc, argv, arg_list)) != -1)
 #endif
-    switch (ch) {
+      switch (ch) {
       case 'a':
         xfree(audio_file);
         if (NULL != optarg) {
@@ -429,6 +431,12 @@ getargs(int argc, char **argv)
 #endif
         break;
 
+      case 'I':
+        xfree(http_instance);
+        http_instance = strdup(optarg);
+        VERBOSE(printf("[c] Instance name: %s\n", http_instance));
+        break;
+
       case 'N':
         usage_statistics = 0;
         VERBOSE(printf("[c] Not sending statistics usage\n"));
@@ -437,7 +445,7 @@ getargs(int argc, char **argv)
       default:
         usage();
         break;
-    }
+      }
 
   if (NULL == base_dir) {
     base_dir = strdup(DEFAULT_PLUGINSDIR);
