@@ -222,7 +222,7 @@ void Context_set_engine_random_mode(Context_t *, const enum RandomMode);
 void Context_insert_plugin(Context_t *, Plugin_t *);
 void Context_remove_plugin(Context_t *, Plugin_t *);
 
-void Context_screenshot(Context_t *);
+void Context_screenshot(Context_t *, const u_char);
 int Context_fps(const Context_t *);
 
 void Context_first_sequence(Context_t *);
