@@ -32,7 +32,8 @@
 #define BARSIZE (HEIGHT/20) // Colormap bar size
 
 extern uint64_t frames;
-extern uint8_t max_fps;
+extern uint8_t  max_fps;
+extern uint8_t  encoding;
 
 
 static void
@@ -70,7 +71,7 @@ Context_sync(Context_t *ctx)
   }
   ctx->fps[i] = (rrt > 0) ? (1.0 / rrt) : 0.0;
 
-  if (sleep > 0) {
+  if (!encoding && (sleep > 0)) {
     ms_sleep(sleep * MFACTOR);
   }
 
@@ -351,7 +352,7 @@ Context_run(Context_t *ctx)
 
     // Screenshot
     if (ctx->take_screenshot) {
-      Context_screenshot(ctx);
+      Context_screenshot(ctx, 0);
       ctx->take_screenshot = 0;
     }
 
