@@ -21,6 +21,9 @@
 #include "colormaps.h"
 
 
+extern uint16_t http_port;
+
+
 static void
 Context_set_colormap(Context_t *ctx)
 {
@@ -111,7 +114,10 @@ Context_set(Context_t *ctx)
   ctx->bandpass_min = ctx->sm->cur->bandpass_min;
   ctx->bandpass_max = ctx->sm->cur->bandpass_max;
   Sequence_display(ctx->sm->cur);
-  Context_websocket_send_sequence(ctx);
+
+  if (http_port) {
+    Context_websocket_send_sequence(ctx);
+  }
 
   okdone("Context_set");
 }
