@@ -70,3 +70,6 @@ uint8_t launch_browser = 1;
 // volume scaling */
 double volume_scale = 1.0;
 
+// Web UI
+uint16_t http_port = 30542;
+char *http_instance = NULL;
