@@ -21,7 +21,7 @@
 
 
 Image8_t *
-Image8_new()
+Image8_new(void)
 {
   Image8_t *p = NULL;
 
