@@ -39,6 +39,14 @@ static uint16_t filter_BLUR2_3x3[3*3] = {
   0, 1, 0
 };
 
+#define FILTER_BLUR3_3x3_SIZE 3
+#define FILTER_BLUR3_3x3_SUM 8
+static uint16_t filter_BLUR3_3x3[3*3] = {
+  0, 2, 0,
+  1, 2, 1,
+  0, 2, 0
+};
+
 #define FILTER_BLUR4_3x3_SIZE 3
 #define FILTER_BLUR4_3x3_SUM 32
 static uint16_t filter_BLUR4_3x3[3*3] = {
@@ -134,6 +142,23 @@ image_filter_average(Buffer8_t *dst, const Buffer8_t *src, enum FilterType type,
         }
       break;
 
+    case FT_BLUR3_3x3:
+      filter = filter_BLUR3_3x3;
+      size   = FILTER_BLUR3_3x3_SIZE;
+      sum_f  = FILTER_BLUR3_3x3_SUM;
+
+      for (uint16_t j = 1; j < MAXY; j++)
+        for (uint16_t i = 1; i < MAXX; i++) {
+          uint32_t sum = get_pixel_nc(src, i - 1, j);
+          sum += get_pixel_nc(src, i, j - 1) * 2;
+          sum += get_pixel_nc(src, i, j) * 2;
+          sum += get_pixel_nc(src, i, j + 1) * 2;
+          sum += get_pixel_nc(src, i + 1, j);
+
+          set_pixel_nc(dst, i, j, (Pixel_t)(sum / FILTER_BLUR3_3x3_SUM));
+        }
+      break;
+
     case FT_BLUR4_3x3:
       filter = filter_BLUR4_3x3;
       size   = FILTER_BLUR4_3x3_SIZE;
