@@ -18,6 +18,7 @@
  */
 
 #include "biniou.h"
+#include "pthread_utils.h"
 
 // All input plugins are stereo
 // #define WITH_MONO_INPUT
@@ -76,6 +77,10 @@ Input_clamp(const double val)
 Input_t *
 Input_new(const uint32_t size)
 {
+  if (size < 64) {
+    xerror("%s: Input size should be >= 64 (wanted %d)\n", __func__, size);
+  }
+
   Input_t *input = xcalloc(1, sizeof(Input_t));
   uint8_t c;
 
@@ -86,8 +91,8 @@ Input_new(const uint32_t size)
   input->mute = 0;
   input->spectrum_size = (input->size / 2) + 1;
 
-  VERBOSE(printf("[w] data size= %d, power spectrum size= %d\n",
-                 input->size, input->spectrum_size));
+  VERBOSE(printf("[i] %s: data size= %d, power spectrum size= %d\n",
+                 __func__, input->size, input->spectrum_size));
 
   for (c = 0; c < 3; c++) {
     uint16_t i;
@@ -352,100 +357,98 @@ Input_process(Input_t *input)
 
   assert(NULL != input);
 
-  xpthread_mutex_lock(&input->mutex);
-  /* run thru history to get history averages and max */
-  input->maxpeak = 0.0;
-  sum = 0.0;
-  for (i = 0; i < HISTORY_SIZE; i++) {
-    tmp = fabs(history_buff[A_MONO][i]);
-    if (tmp > input->maxpeak) {
-      input->maxpeak = tmp;
+  if (!xpthread_mutex_lock(&input->mutex)) {
+    /* run through history to get history averages and max */
+    input->maxpeak = 0.0;
+    sum = 0.0;
+    for (i = 0; i < HISTORY_SIZE; i++) {
+      tmp = fabs(history_buff[A_MONO][i]);
+      if (tmp > input->maxpeak) {
+        input->maxpeak = tmp;
+      }
+      sum += tmp;
     }
-    sum += tmp;
-  }
-  input->average = sum / HISTORY_SIZE;
+    input->average = sum / HISTORY_SIZE;
 
-  /* one more loop on whole history, to collect peaks we have */
-  j = 0;
-  tmp = -1.0;
-  for (i = 0; i < HISTORY_SIZE; i++) {
-    sum = fabs(history_buff[A_MONO][i]);
-    if (sum > (input->average + (input->maxpeak - input->average) * PEAK_ABOVE_AVG)) {
-      if (tmp < 0.0) { /* new peak */
-        /* if we are very near previous peak, continue with it */
-        if ((j > 0) && (i < (peaks[1][j-1] + PEAK_DURATION))) {
-          tmp = (peak_val[j-1] > sum) ? peak_val[j-1] : sum;
-          peaks[1][j-1] = i;
-        } else { /* really new peak */
-          peaks[0][j] = i;
-          tmp = sum;
-          j++;
-          if (j >= PEAK_MAX_COUNT) {
-#ifdef DEBUG
-            printf("**** Got more than %d peaks\n", PEAK_MAX_COUNT);
-#endif
-            break;
+    /* one more loop on whole history, to collect peaks we have */
+    j = 0;
+    tmp = -1.0;
+    for (i = 0; i < HISTORY_SIZE; i++) {
+      sum = fabs(history_buff[A_MONO][i]);
+      if (sum > (input->average + (input->maxpeak - input->average) * PEAK_ABOVE_AVG)) {
+        if (tmp < 0.0) { /* new peak */
+          /* if we are very near previous peak, continue with it */
+          if ((j > 0) && (i < (peaks[1][j-1] + PEAK_DURATION))) {
+            tmp = (peak_val[j-1] > sum) ? peak_val[j-1] : sum;
+            peaks[1][j-1] = i;
+          } else { /* really new peak */
+            peaks[0][j] = i;
+            tmp = sum;
+            j++;
+            if (j >= PEAK_MAX_COUNT) {
+              xdebug("**** Got more than %d peaks\n", PEAK_MAX_COUNT);
+              break;
+            }
           }
+        } else { /* still in same peak */
+          if (sum > tmp) {
+            tmp = sum;
+          }
+          peaks[1][j-1] = i;
         }
-      } else { /* still in same peak */
-        if (sum > tmp) {
-          tmp = sum;
+      } else { /* not in peak */
+        if (tmp > 0.0) { /* first non-peak value after peak */
+          peak_val[j-1] = tmp;
+          tmp = -1.0;
         }
-        peaks[1][j-1] = i;
-      }
-    } else { /* not in peak */
-      if (tmp > 0.0) { /* first non-peak value after peak */
-        peak_val[j-1] = tmp;
-        tmp = -1.0;
       }
     }
-  }
-  /* now loop the found peaks, and try to find suitable limit */
-  count = 0;
-  for (limit = 0.99;
-       count < PEAK_COUNT_ON_HISTORY && limit > PEAK_ABOVE_AVG;
-       limit -= 0.01) {
+    /* now loop the found peaks, and try to find suitable limit */
     count = 0;
-    for (i = 0; i < j; i++) {
-      if (peak_val[i] >
-          (input->average + (input->maxpeak - input->average) * limit)) {
-        count++;
+    for (limit = 0.99;
+         count < PEAK_COUNT_ON_HISTORY && limit > PEAK_ABOVE_AVG;
+         limit -= 0.01) {
+      count = 0;
+      for (i = 0; i < j; i++) {
+        if (peak_val[i] >
+            (input->average + (input->maxpeak - input->average) * limit)) {
+          count++;
+        }
       }
     }
-  }
 
-  /* copy data for plugin usage from ring buffer and get peaks */
-  input->size2 = 0;
-  input->curpeak = 0.0;
-  sum = 0.0;
-  sqsum = 0.0;
-  while (history_rd != history_wr) {
-    input->data2[A_MONO][input->size2] = history_buff[A_MONO][history_rd];
-    input->data2[A_LEFT][input->size2] = history_buff[A_LEFT][history_rd];
-    input->data2[A_RIGHT][input->size2] = history_buff[A_RIGHT][history_rd];
-    tmp = fabs(history_buff[A_MONO][history_rd]);
-    sum += tmp;
-    sqsum += 100 * tmp * tmp;
-    if (tmp > input->curpeak) {
-      input->curpeak = tmp;
+    /* copy data for plugin usage from ring buffer and get peaks */
+    input->size2 = 0;
+    input->curpeak = 0.0;
+    sum = 0.0;
+    sqsum = 0.0;
+    while (history_rd != history_wr) {
+      input->data2[A_MONO][input->size2] = history_buff[A_MONO][history_rd];
+      input->data2[A_LEFT][input->size2] = history_buff[A_LEFT][history_rd];
+      input->data2[A_RIGHT][input->size2] = history_buff[A_RIGHT][history_rd];
+      tmp = fabs(history_buff[A_MONO][history_rd]);
+      sum += tmp;
+      sqsum += 100 * tmp * tmp;
+      if (tmp > input->curpeak) {
+        input->curpeak = tmp;
+      }
+      history_rd++;
+      input->size2++;
+      if (history_rd >= HISTORY_SIZE) {
+        history_rd = 0;
+      }
     }
-    history_rd++;
-    input->size2++;
-    if (history_rd >= HISTORY_SIZE) {
-      history_rd = 0;
+    input->volume = sum / input->size2;
+    input->rms = sqrt(sqsum/input->size2);
+    if (input->curpeak >
+        (input->average + (input->maxpeak - input->average) * limit)) {
+      input->on_beat = 1;
+    } else {
+      input->on_beat = 0;
     }
+    input->peakpower = input->curpeak*input->curpeak;
+    xpthread_mutex_unlock(&input->mutex);
   }
-  input->volume = sum / input->size2;
-  input->rms = sqrt(sqsum/input->size2);
-  if (input->curpeak >
-      (input->average + (input->maxpeak - input->average) * limit)) {
-    input->on_beat = 1;
-  } else {
-    input->on_beat = 0;
-  }
-  input->peakpower = input->curpeak*input->curpeak;
-  xpthread_mutex_unlock(&input->mutex);
-
 }
 
 
