@@ -45,9 +45,20 @@ screenshot_filename(void)
 
 
 void
-Context_screenshot(Context_t *ctx)
+Context_screenshot(Context_t *ctx, const u_char frame_number_mode)
 {
-  gchar *filename = screenshot_filename();
+  gchar *filename = NULL;
+
+  if (frame_number_mode) {
+    extern uint64_t frames;
+    char *video_filename = getenv("LEBINIOU_MP4_FILENAME");
+    if (NULL == video_filename) {
+      xerror("%s: frame_number_mode set but no encoding in progress ?\n", __func__);
+    }
+    filename = g_strdup_printf("%s-%06"PRIu64".png", video_filename, frames);
+  } else {
+    filename = screenshot_filename();
+  }
   FILE* fp = fopen(filename, "wb");
 
   if (NULL == fp) {
@@ -66,7 +77,9 @@ Context_screenshot(Context_t *ctx)
     if (fclose(fp) != 0) {
       xperror("fclose");
     }
-    VERBOSE(printf("[i] %s: saved screenshot to %s\n", __FILE__, filename));
+    if (!frame_number_mode) {
+      VERBOSE(printf("[i] %s: saved screenshot to %s\n", __FILE__, filename));
+    }
     g_free(filename);
   }
 }
