@@ -124,7 +124,10 @@ void
 Sequence_delete(Sequence_t *s)
 {
   if (NULL != s) {
-    VERBOSE(printf("[s] Freeing sequence id %"PRIu64"\n", s->id));
+    // FIXME -q is not taken into account when running tests
+    if (NULL == getenv("LEBINIOU_TEST")) {
+      VERBOSE(printf("[s] Freeing sequence id %"PRIu64"\n", s->id));
+    }
 
     GList *tmp = s->layers;
     while (NULL != tmp) {
@@ -156,7 +159,10 @@ Sequence_display(const Sequence_t *s)
   if (NULL == s) {
     xerror("Attempt to display a NULL Sequence\n");
   } else {
-    VERBOSE(printf("[s] Sequence id: %"PRIu64"\n", s->id));
+    // FIXME -q is not taken into account when running tests
+    if (NULL == getenv("LEBINIOU_TEST")) {
+      VERBOSE(printf("[s] Sequence id: %"PRIu64"\n", s->id));
+    }
   }
 
   uint8_t v = libbiniou_verbose;
