@@ -31,15 +31,16 @@ typedef struct Sequences_s {
 } Sequences_t;
 
 
-void Sequences_new();
-void Sequences_delete();
+void Sequences_new(void);
+void Sequences_delete(void);
 
-GList *Sequences_find(const uint32_t);
+GList *Sequences_find(const uint64_t);
 GList *Sequences_find_by_name(const char *);
 GList *Sequences_find_last_updated(GList *);
 
 void Sequences_set_dir(gchar *);
-const gchar *Sequences_get_dir();
+const gchar *Sequences_get_dir(void);
 
+void Sequences_remove_sequence_by_name(const char *);
 
 #endif /* __BINIOU_SEQUENCES_H */
